@@ -1,7 +1,7 @@
 /*
  * decl - variable and function declaration macros
  *
- * Copyright (C) 2007,2014  Landon Curt Noll
+ * Copyright (C) 2007,2014,2021  Landon Curt Noll
  *
  * Primary author:  Landon Curt Noll
  *
@@ -11,7 +11,7 @@
  *
  * Calc is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU Lesser General
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General
  * Public License for more details.
  *
  * A copy of version 2.1 of the GNU Lesser General Public License is
@@ -19,10 +19,10 @@
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * Under source code control:	2007/02/09 05:24:25
- * File existed as early as:	2007
+ * Under source code control:   2007/02/09 05:24:25
+ * File existed as early as:    2007
  *
- * Share and enjoy!  :-)	http://www.isthe.com/chongo/tech/comp/calc/
+ * Share and enjoy!  :-)        http://www.isthe.com/chongo/tech/comp/calc/
  */
 
 
@@ -37,7 +37,7 @@
  * Thread Local Storage macros
  *
  * NOTE: The use of -DWITH_TLS is extremely experimental.  Calc may not
- *	 compile with WITH_TLS defined.
+ *       compile with WITH_TLS defined.
  */
 #if defined(WITH_TLS)
 
@@ -52,9 +52,9 @@
 
 
 /*
- * MS windoz macros
+ * MS Windows macros
  */
-#elif defined(_WIN32) || defined(WINDOZ)
+#elif defined(_WIN32) || defined(_WIN64)
 
 
   /* determine which type of DLL we must generate */
@@ -94,12 +94,5 @@
 
 #endif
 
-/* Perform printf-style argument type checking for known compilers */
-#ifdef __GNUC__
-# define PRINTF_FORMAT(fmt_idx, arg_idx) __attribute__ \
-         ((format (printf, fmt_idx, arg_idx)))
-#else
-# define PRINTF_FORMAT(fmt_idx, arg_idx)
-#endif
 
 #endif /* !INCLUDE_DECL_H */
